globalVariables(
    names = c('.indexes', 'adn', '.sectors', 'Box.test', 'Close', 'Countries', 'Date', 'High', 'Low', 'Open', 'POST',
              'Sector', 'Ticker', 'Desc.BRVM.all', 'Volume', 'ad.test', 'adf.test', 'arrange', 'as.xts', 'color_tile',
              'content', 'dagoTest', 'desc', 'direction', 'formattable', 'formatter', 'global_env',
              'hc_add_series', 'hc_add_yAxis', 'hc_colors', 'hc_exporting', 'hc_title', 'hc_xAxis',
              'hc_yAxis_multiples', 'hcaes', 'highchart', 'html_nodes', 'html_table', 'is.ts',
              'isWeekday', 'jarque.bera.test', 'kpss.test', 'left_join', 'lillie.test', 'na.omit',
              'na.remove', 'pearson.test', 'pp.test', 'read_html', 'req_body_json', 'req_perform',
              'request', 'resp_body_json', 'sf.test', 'shapiro.test', 'str_replace', 'str_sub',
              'str_to_title', 'summarise', 'html_elements', 'adn_ticker',
              # 'across', 'all_of',
              'numeric_columns'
              )
    )
